==> kleopatra-16.08.0.tar.xz: kleopatra-16.08.0/src/commands/signencryptfoldercommand.cpp <==
/* -*- mode: c++; c-basic-offset:4 -*-
    commands/signencryptfoldercommand.cpp

    This file is part of Kleopatra, the KDE keymanager
    Copyright (c) 2016 Intevation GmbH

    Kleopatra is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    Kleopatra is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA

    In addition, as a special exception, the copyright holders give
    permission to link the code of this program with any edition of
    the Qt library by Trolltech AS, Norway (or with modified versions
    of Qt that use the same license as Qt), and distribute linked
    combinations including the two.  You must obey the GNU General
    Public License in all respects for all of the code used other than
    Qt.  If you modify this file, you may extend this exception to
    your version of the file, but you are not obligated to do so.  If
    you do not wish to do so, delete this exception statement from
    your version.
*/

#include <config-kleopatra.h>

#include "signencryptfoldercommand.h"

#include <KLocalizedString>

#include <QStringList>
#include <QApplication>
#include <QFileDialog>

using namespace Kleo;
using namespace Kleo::Commands;

SignEncryptFolderCommand::SignEncryptFolderCommand(QAbstractItemView *v, KeyListController *c)
    : SignEncryptFilesCommand(v, c)
{
    setArchivePolicy(Force);
}

SignEncryptFolderCommand::SignEncryptFolderCommand(KeyListController *c)
    : SignEncryptFolderCommand(Q_NULLPTR, c)
{
}

QStringList SignEncryptFolderCommand::selectFiles() const
{
    const QString dir = QFileDialog::getExistingDirectory(qApp->activeWindow(),
                                                          i18n("Select Folder to Sign and/or Encrypt"));
    if (dir.isNull()) {
        return QStringList();
    }
    return QStringList() << dir;
}

==> kleopatra-17.04.1.tar.xz: kleopatra-17.04.1/src/commands/signencryptfoldercommand.cpp <==
/* -*- mode: c++; c-basic-offset:4 -*-
    commands/signencryptfoldercommand.cpp

    This file is part of Kleopatra, the KDE keymanager
    Copyright (c) 2016 Intevation GmbH

    Kleopatra is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    Kleopatra is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA

    In addition, as a special exception, the copyright holders give
    permission to link the code of this program with any edition of
    the Qt library by Trolltech AS, Norway (or with modified versions
    of Qt that use the same license as Qt), and distribute linked
    combinations including the two.  You must obey the GNU General
    Public License in all respects for all of the code used other than
    Qt.  If you modify this file, you may extend this exception to
    your version of the file, but you are not obligated to do so.  If
    you do not wish to do so, delete this exception statement from
    your version.
*/

#include <config-kleopatra.h>

#include "signencryptfoldercommand.h"

#include <KLocalizedString>

#include <QStringList>
#include <QApplication>
#include <QFileDialog>

using namespace Kleo;
using namespace Kleo::Commands;

SignEncryptFolderCommand::SignEncryptFolderCommand(QAbstractItemView *v, KeyListController *c)
    : SignEncryptFilesCommand(v, c)
{
    setArchivePolicy(Force);
}

SignEncryptFolderCommand::SignEncryptFolderCommand(KeyListController *c)
    : SignEncryptFolderCommand(nullptr, c)
{
}

QStringList SignEncryptFolderCommand::selectFiles() const
{
    const QString dir = QFileDialog::getExistingDirectory(qApp->activeWindow(),
                                                          i18n("Select Folder to Sign and/or Encrypt"));
    if (dir.isNull()) {
        return QStringList();
    }
    return QStringList() << dir;
}
